package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`\P`!````3!\```````!```````````"D````
M````!0```$``.``*`$``&@`9``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````A`````````"$``````````0`````````#``!P
M!````*VB`````````````````````````````%,````````````````````!
M``````````$````%````````````````````````````````````6),`````
M``!8DP`````````0`````````0````8```#8G0```````-BM````````V*T`
M``````"P!````````-@$`````````!`````````"````!@```/"=````````
M\*T```````#PK0```````!`"````````$`(````````(``````````0````$
M````E`(```````"4`@```````)0"````````1`````````!$``````````0`
M````````4.5T9`0````PC````````#",````````,(P```````#D````````
M`.0`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````V)T```````#8
MK0```````-BM````````*`(````````H`@````````$`````````+VQI8B]L
M9"UL:6YU>"UR:7-C=C8T+6QP-C1D+G-O+C$`````!````!0````#````1TY5
M`,4!(;94*2GK;4)D9$E1ELHJYGO"!````!`````!````1TY5```````$````
M#P`````````1````1@````0````(````()`0`05`!,0H`@$$@(8$A(()```)
M(`0(B(`00;H``H@`````1@```$D```!,````30```%0```!5````5P```%D`
M``!:````6P```%T```!?````8````&(``````````````&[%WQ_.WD<M:W^:
M?"[%F[;49-1\(?_D#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGS[H6Q@
M:PE#UF:OS&89?@J'0D75[(D'<--S4)_8,V+;[3[/TFP5C"7,##J7"_]A\F%_
MJ9R;X*<""FL:GE"CX/M)``````````````````````````````````````,`
M#`#`'0``````````````````S`(``!$`````````````````````````U0``
M`!(`````````````````````````]`$``!(`````````````````````````
ML@$``!(`````````````````````````AP```!(`````````````````````
M````3@$``!(`````````````````````````N@$``!(`````````````````
M````````)0(``!(`````````````````````````90$``!(`````````````
M````````````5`(``!(`````````````````````````ZP```!(`````````
M````````````````D@(``!(`````````````````````````L@(``!$`````
M````````````````````P0$``!(`````````````````````````[P$``!(`
M````````````````````````'`$``!(`````````````````````````#`$`
M`!(`````````````````````````_@```!(`````````````````````````
MC@$``!(`````````````````````````'@(``!(`````````````````````
M````^P$``!(`````````````````````````N@(``!(`````````````````
M`````````0```"``````````````````````````1`(``!(`````````````
M````````````;`$``!(`````````````````````````'0```"``````````
M````````````````=@(``!(`````````````````````````;`(``!(`````
M````````````````````-P```!(`````````````````````````?0(``!(`
M````````````````````````L`(``!$`````````````````````````5```
M`!8`````````````````````````J0(``!(`````````````````````````
M/@$``!(`````````````````````````I@$``!(`````````````````````
M````9P```!(`````````````````````````7@(``!(`````````````````
M````````Q````!(`````````````````````````>````!(`````````````
M````````````A@$``!(`````````````````````````J````!(`````````
M````````````````V@```!(`````````````````````````=P$``!(`````
M````````````````````?P$``!(`````````````````````````HP(``!(`
M````````````````````````,`$``!(`````````````````````````%P(`
M`!(`````````````````````````+`(``!(`````````````````````````
M90(``!$`````````````````````````WP```!(`````````````````````
M````YP$``!(`````````````````````````=0(``!(`````````````````
M````````T`$``"(`````````````````````````DP```!(`````````````
M````````````WP$``!(`````````````````````````K0$``!(`````````
M````````````````30(``!(`````````````````````````60$``!(`````
M`````````````````````@(``!(`````````````````````````E`,``!(`
M````````````````````````MP```!$`````````````````````````A`(`
M`!(`````````````````````````)0$``!(`````````````````````````
M10```!(`````````````````````````E`$``!(`````````````````````
M````R`$``!(`````````````````````````,P(``!(`````````````````
M````````$`(``!(`````````````````````````G0,``!(`#`#F-```````
M`*@`````````+P0``!(`#`!T+@```````,($````````H0$``!(`#`#`'0``
M`````(P!````````%`,``!(`#`#B)@````````(`````````,@,``!(`#``V
M,P```````+`!````````500``!(`#`#D)@```````-8!````````%00``!``
M%@"(L@``````````````````)0,``!(`#`"Z*````````"(`````````2`,`
M`!(`#``V+0```````$X`````````M0,``!$`#0#H2@````````0`````````
M\@,``!(`#`!,2````````-P`````````#00``!(`#`#\)0```````"@`````
M````*@0``!``%@"PL@``````````````````0P0``!(`#`"<+0```````-@`
M````````Q`,``!``%```L```````````````````;`,``!(`#`#<*```````
M``(!````````X`,``!``\?\`N```````````````````/`0``!``%0"(L@``
M````````````````8@0``!$`%`!(L`````````@`````````_0,``!``%0"(
ML@``````````````````R@,``!(`#`!,'P```````"(`````````T0,``!``
M%```L```````````````````(00``!(`#`#X1P```````%0`````````Q@,`
M`"``%```L```````````````````J0,``!``%@"PL@``````````````````
M@@,``!(`#`"$+0```````!@`````````5@,``!(`#``D)@```````+X`````
M````>`,``!(`#``H20```````+(!````````;`0``!(`#`#>*0```````%@#
M`````````%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES
M=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`
M4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS
M=')U8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]S
M=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA9W,`<&5R;%]F
M<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E
M='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7VYE=UA3`'!E<FQ?
M9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E
M<WES;6%L;&]C`'!E<FQ?86QL;V,`;65M;6]V90!S=')C:'(`;'-E96LV-`!R
M;61I<@!?7VQI8F-?<W1A<G1?;6%I;@!S=')C;7``<F5A9`!S=')N8VUP`&=E
M='5I9`!A8V-E<W,`;W!E;F1I<@!?7V-X85]F:6YA;&EZ90!R96%L;&]C`'-T
M<G)C:'(`97AI=`!S=')T;VL`=6YL:6YK`%]?9G!R:6YT9E]C:&L`;W!E;C8T
M`'-T<F1U<`!S=')S='(`<W1R;&5N`&UE;6-H<@!?7W-T86-K7V-H:U]F86EL
M`')E861L:6YK`&UE;7-E=`!R96%D9&ER-C0`;65M8VUP`'-T9&5R<@!C;&]S
M961I<@!L<W1A=#8T`&UE;6-P>0!?7W-P<FEN=&9?8VAK`%]?97)R;F]?;&]C
M871I;VX`;6MD:7(`9V5T<&ED`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R
M:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L+G-O+C4N,S8`;&EB8RYS;RXV
M`&QD+6QI;G5X+7)I<V-V-C0M;'`V-&0N<V\N,0!P87)?8W5R<F5N=%]E>&5C
M`'!A<E]B87-E;F%M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C
M;&5A;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I
M;F%L`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]?
M0E-37T5.1%]?`%])3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!?7T1!5$%?
M0D5'24Y?7P!?7V=L;V)A;%]P;VEN=&5R)`!S:&%?=7!D871E`%]?4T1!5$%?
M0D5'24Y?7P!X<U]I;FET`%]?8G-S7W-T87)T`'-H85]I;FET`%]E;F0`<&%R
M7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R
M;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C,T`$=,24)#7S(N
M,S,`1TQ)0D-?,BXR-P```````@`!``,``P`!``$``P`#``,``P`!``,``P`#
M``,``0`!``$``P`#``,``P`!``,``0`!``0``P`!``,``P`!``,``0`#``$`
M`P`!``$``P`!``,``P`#``,``0`#``,``P`!``,`!``#``$``P`#``,``0`#
M``,``0`#``$``0`%``,``P`#``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``,`[@(``!````!`
M````M)&6!@``!0!Y!```$````+.1E@8```0`A`0``!````"'D98&```#`(\$
M`````````0`!`/@"```0`````````(>1E@8```(`CP0```````#8K0``````
M``,`````````;A\```````#@K0````````,``````````B````````#HK0``
M``````,`````````R!\`````````L`````````,``````````+`````````8
ML`````````,`````````2$P````````@L`````````,`````````@$X`````
M```HL`````````,`````````B$X````````PL`````````,`````````D$X`
M```````XL`````````,`````````F$X```````!(L`````````,`````````
MH$X```````"`L@````````,`````````P!T````````HL@````````(````"
M```````````````PL@````````(````,```````````````XL@````````(`
M```.``````````````!`L@````````(````8``````````````!(L@``````
M``(````;``````````````!0L@````````L````A``````````````!8L@``
M``````(````C``````````````!@L@````````(````E``````````````!H
ML@````````(````R``````````````!PL@````````(````V````````````
M``!XL@````````(````^``````````````!@L`````````4````#````````
M``````!HL`````````4````$``````````````!PL`````````4````%````
M``````````!XL`````````4````&``````````````"`L`````````4````'
M``````````````"(L`````````4````(``````````````"0L`````````4`
M```)``````````````"8L`````````4````*``````````````"@L```````
M``4````+``````````````"HL`````````4````-``````````````"PL```
M``````4````/``````````````"XL`````````4````0``````````````#`
ML`````````4````1``````````````#(L`````````4````2````````````
M``#0L`````````4````3``````````````#8L`````````4````4````````
M``````#@L`````````4````5``````````````#HL`````````4````6````
M``````````#PL`````````4````7``````````````#XL`````````4````9
M````````````````L0````````4````:```````````````(L0````````4`
M```<```````````````0L0````````4````=```````````````8L0``````
M``4````>```````````````@L0````````4````?```````````````HL0``
M``````4````B```````````````PL0````````4````D```````````````X
ML0````````4````F``````````````!`L0````````4````G````````````
M``!(L0````````4````H``````````````!0L0````````4````I````````
M``````!8L0````````4````J``````````````!@L0````````4````K````
M``````````!HL0````````4````L``````````````!PL0````````4````M
M``````````````!XL0````````4````N``````````````"`L0````````4`
M```O``````````````"(L0````````4````P``````````````"0L0``````
M``4````Q``````````````"8L0````````4````S``````````````"@L0``
M``````4````T``````````````"HL0````````4````U``````````````"P
ML0````````4````W``````````````"XL0````````4````X````````````
M``#`L0````````4````Y``````````````#(L0````````4````Z````````
M``````#0L0````````4````[``````````````#8L0````````4````\````
M``````````#@L0````````4````]``````````````#HL0````````4````_
M``````````````#PL0````````4```!```````````````#XL0````````4`
M``!!````````````````L@````````4```!"```````````````(L@``````
M``4```!#```````````````0L@````````4```!$```````````````8L@``
M``````4```!%`````````````````````````)>3```S`\-!`[X#8Q,#0_V3
M@@-C$U,3`(.R@@!G``X`%YX```,^#F)G`PX`$P```!>>```#/HYA9P,.`!,`
M```7G@```SX.86<##@`3````%YX```,^CF!G`PX`$P```!>>```#/@Y@9P,.
M`!,````7G@```SZ.7V<##@`3````%YX```,^#E]G`PX`$P```!>>```#/HY>
M9P,.`!,````7G@```SX.7F<##@`3````%YX```,^CEUG`PX`$P```!>>```#
M/@Y=9P,.`!,````7G@```SZ.7&<##@`3````%YX```,^#EQG`PX`$P```!>>
M```#/HY;9P,.`!,````7G@```SX.6V<##@`3````%YX```,^CEIG`PX`$P``
M`!>>```#/@Y:9P,.`!,````7G@```SZ.66<##@`3````%YX```,^#EEG`PX`
M$P```!>>```#/HY89P,.`!,````7G@```SX.6&<##@`3````%YX```,^CE=G
M`PX`$P```!>>```#/@Y79P,.`!,````7G@```SZ.5F<##@`3````%YX```,^
M#E9G`PX`$P```!>>```#/HY59P,.`!,````7G@```SX.56<##@`3````%YX`
M``,^CE1G`PX`$P```!>>```#/@Y49P,.`!,````7G@```SZ.4V<##@`3````
M%YX```,^#E-G`PX`$P```!>>```#/HY29P,.`!,````7G@```SX.4F<##@`3
M````%YX```,^CE%G`PX`$P```!>>```#/@Y19P,.`!,````7G@```SZ.4&<#
M#@`3````%YX```,^#E!G`PX`$P```!>>```#/HY/9P,.`!,````7G@```SX.
M3V<##@`3````%YX```,^CDYG`PX`$P```!>>```#/@Y.9P,.`!,````7G@``
M`SZ.36<##@`3````%YX```,^#DUG`PX`$P```!>>```#/HY,9P,.`!,````7
MG@```SX.3&<##@`3````%YX```,^CDMG`PX`$P```!>>```#/@Y+9P,.`!,`
M```7G@```SZ.2F<##@`3````%YX```,^#DIG`PX`$P```!>>```#/HY)9P,.
M`!,````7G@```SX.26<##@`3````%YX```,^CDAG`PX`$P```!>>```#/@Y(
M9P,.`!,````7G@```SZ.1V<##@`3````%YX```,^#D=G`PX`$P```!>>```#
M/HY&9P,.`!,````=<8;LIN2JAZ+HRN!._)>4``"#M*1%+N@RY`P(,`!H"#[.
MG&`^](%'[_"?^!>6```#-D9$LH47E0```S6E1N\@T$V7EP``@[=G1X/'!P#Q
MSY>7``"#MP=$%Y0``!,$A$>2EYAC<DF#1Z=*&P5)``X%D^<W`",%]TKO\)_N
MPF7R1PCDF&$-*:J&&.$7-P``$P=G`ACE%Y<```,W1Q\8Z1<W```3!Z<!&.T%
M1V-:]PP;B#<`0H:A!1%'B&&3%S<`MI<%)XCCH07C&0?_FP<&``ALC@>VETJ&
M`4>7!0``DX6E<".P!P#O\-^]*HDUQ0ALDPE!`N_P_]S.A1<U```3!072[P!`
M%#'-"&SO\)^W[_!?SB)WG&"YCP%'I>OF8$9DIF3B>4J%!FDE88*`[_!_R1>4
M```3!"0Z".PIQ>_P?]&7EP``@[<G-85F,X='`!AC-I>C"P>D,;<(;._PG[XJ
MB7FW"&@!Q>\0(%QYO\Z%%S4``!,%1</O```-".A1U>6WD4>YMP5%[_#?NN_P
MG^7O`"`"JH<7E0```S7E,H)E,``3<0'_@48!1PJ([_"?X0*0EZ$``).!(8F"
M@```%Y4``!,%90V7EP``DX?G#&.(IP"7EP``@[<G*Y'#@H>"@!>5```3!44+
MEY4``).%Q0J)C9/7-4#]D;Z5A869Q9>7``"#M^<HD<."AX*`01$BX!>4```3
M!,0K@T<$``;DA>.7EP``@[='*9''%Y4```,UI0&"E^_PO_B%1R,`]`"B8`)D
M00&"@&F_.7$&_"+X6<5:X)>7``"#MZ<B`[L'`&,!"PA*\$[L4NB#1P4`JHDN
MBBJ)$P?0`Z7+8X;G`(-'&0`%"?W[.PDY00,T"P`YS";T5N3:A),*T`-*ALZ%
M(H7O\'^@LP<D`0GE@\<'`&.`5P.`9*$$=?"B=`)YXFE":J)J`FOB<"*%0G0A
M88*`LX1D08V$!0DC()H`2I3QOP%$U;<":P%$^;\!246W`GGB:4)J`FO!OW%Q
M(O$F[0;UEY0``(.T!!<L`)Q@/N6!1RJ$[_!_P`WAXD>]9A%G]8]CA><`*6=C
MFN<`B44BA>_POY\3-14`$:`!12IGG&"YCP%'D>>J<`ITZF1-88*`[_"_R3%Q
M3NT&_9>9``"#N8D1@[<)`#[E@4<9Q2+Y@T<%`"J$B>]*="IG@[<)`+F/`4=C
ME@<,ZG#J:2EA@H`F]4KQ[_"?Q*J$4<DFA>_P_Y9!P8-&-0$3"34!FX8F_8'F
M@T89`/W2`T<U`1L')_T]RR*%4NGO\'^2*HI*A>_P_Y$[!:H`"27O\%^2RH<B
MAY<V``"3AL:5?5:%12J)[_#_NBP`2H7O\'^>_5=C"/4`XD>]9A%G]8]C@.<$
M2H7O\/^82H7O\)^G)H5*:N_P'X]1\2:%[_"?G"*%[_`_E4ITJG0*>9FW`T<9
M`!L')_U1\P-'*0`AW[6_2H7O\-_PT;<B^2;U2O%2Z>_P7[D=<:+HP7)!9$[\
M4OA:\(;LIN3*X%;T7NQBZ!,'A``6D0J7%YL```,[:_^#-PL`'..!1PE&@44J
MBN_PGYV3"?7_$]?Y0T&3LX?I`,(7P9.9C[.)^4!CRPD&P73!%),'!`'!:Z:7
MLX0G`*$+'4P7F0``$PG)V,%Z`4;.A5*%[_!?F5Z&IH52A>_POZ8!)6-\K`(3
M!(7_)I1C=I0`+:!]%&-CE`(A1LJ%(H7O\)^39?G!=T%GP1=!!SZ7LP<G`#,%
M]$!.E2F@UIGCF%G[?57!9Z$'BI>88X,W"P"YCP%'F>_!8A:1YF!&9*9D!FGB
M>4)ZHGH">^)K0FPE88*`[_!_J1UQHNBFY,K@4OB&[$[\5O1:\(/'!0`7F0``
M`SE)\*J$DX<W_).W%P`SA/4`(H6#-PD`/N2!1^_PS_4JBDP`)H7O\'_+><FJ
MB>_PK_1C=D4+DDH7FP```SN+[8X*`\<$`*:'DP;0`V,(!Q)C!M<``\<7`(4'
M??N%GX,Y"P`3!2H`/I76F>_P[_$CL*D`,<4#-PL`@\<$`!.%%`!6EQ1C$P;0
M`R.`]@"!Z[V@@T<%``4%HP#W`*W#-H>%!N.8Q_Z3!M`#DP<7`",`UP`#1P0`
MA0<%!*./Y_YU^R)G@S<)`+F/`4?=[^9@1F2F9`9IXGE">J)Z`GLE88*`@T<$
M`(4)!02CC_G^\=N#1P0`A0D%!*./^?[]\]&W-H==MU[L8N@7FP```SO+X`,\
M"P"#-PP`M<?BAX%)F&?.AJ$'A2EE_XTFDY4V`)>7``"3A^?CF$,5ZP5'+H68
MP^_PS^2JBS'%DYHY`%:&XH7O\,_](S![`9N'&0".![Z;([`+`.)K0FQ.PO&]
M8H7O\/^%(S"K`*J+"<V3FCD`Z;^!1\6UP46!25VW7NQBZ._P_X[B:T)L-;==
M<5;L_7>%:OURX1<3APH!HN`F_$KX3O12\(;D/I<6D:Z)LP4G`!.'B@`*EP5D
M%YD```,YZ=,JBA,&]/\7)0``$P4%8(,W"0`<XX%'[_"/YIL$!0!C7I``$X<*
M`0J7,P2'0)N']/\^E`-'A/\IXYWOEY<``(.W1]).AM*%DI>(8^_P3]Z%9Z$'
MBI>88X,W"0"YCP%'N>>%8A:1IF`&9.)T0GFB>0)ZXFIA88*`OH3]=P5GX1=!
M!SZ7,P0G`":&DP7P`B*%[_`/\D75EY<``(.WI\RFAB*&DI>(8]*%[_"/Z56W
M[_`_@$$1(N`7E````S2DR@;DEV8``).&!F:S!T0`B&,7E@```S:FR9<E``"3
MA254[_`O^1*4"&`"9*)@%S<``!,'YXB!1[J&%Q8``!,&!M67)0``DX6E4T$!
M;_"/X)>7``"#MT?%EV8``).&QF`7E@```S;&Q)*7B&.7)0``DX4%3V_P#_1=
M<2;\^7*)9(;DHN!*^$[T$X>$`1:1"I>7F0``@[G)OH.W"0`<XX%'[_!/V/EW
MH1>3A@0"OI8SA"8`!68JAY<G``"3A^=-ER8``).&YDT%!H5%(H7O\(_M_77!
M%9.'!`*NE[.$)P`BA05FIH7O\`_.&P0%``%)8T\$`!L%%`#O\._`*HD!R2*&
MIH5*E._P#]$C``0`B6?A!XJ7F&.#MPD`N8\!1YGKB6(6D:9@2H4&9.)T0GFB
M>6%A@H#O\"_LB;>%9OUW47']<I.'1_<3AP8)HO&F[<KI8O&&]<[ETN%6_5KY
M7O5F[6KI/I<6D2Z$LP4G`!.'A@@*EQ><```#/,RP*HF#-PP`'..!1Q<E```3
M!25#[_#_C*J$DP7P`DJ%[_#OT2'%%R4``!,%A4+*A>_PW[M*A85GDX>'"(J7
MF&.#-PP`N8\!1V.6!Q2%8A:1KG`.=.YD3FFN:0YJZGI*>ZI["GSJ;$IM;6&"
M@"*%[_`/T)<E``"3A<4^[_!/JRJ$7=&%9_UYX1D3AP<)3I>S"2<`$X<'"9.'
M!PF*EX5J?7JSC%=!@T<$`!,*BO=2EY<K``"3BXL[%RL``!,+BSLS"B<`R<N1
MQ**%)H7O\$^_-<4BA>_PSZJ3!_7_HI<JC9,&\`)C:/0`,:@C@`<`_1=C!O0`
M`\<'`.,)U_XBA>_P+Z@JC4J%[_"OIVJ5!07C?57QA45*B-Z'(H?:A@5F3H7O
M\`_1TH5.A>_PC[0!Z8.GC/B]9B%G]8]CC^<"ER4``).%13(!1>_PKYXJA.,.
M!>R#1P0`K?N1Q(/'!`";AR?]F<<%31<D```3!$0M8;^#QQ0`Z=?]MX5%3H7O
M\&^D7?W.A1<E```3!>4L[_!?IDZ%[_`/OE6U[_"OSD$1DP7P`B+@!N0JA._P
MK[\9P1,$%0`BA0)DHF!!`6_PC[MY<85G_7)*Z`;T(O`F[!.'AP`6D1>9```#
M.8F3"I>#-PD`'..!1TW!@T<%`*J$R<_O\$^9$P85`(5G*H1C[\<*?7=A%\$'
MNI<SAR<`IH4ZA>_P3ZF3!_3_JI>3!O`"8VCU`!&H(X`'`/T78X:G``/'!P#C
M"=?^?76%9V$5P0>JES.$)P"3!?`"(H7O\*^U#<UC8J0&?76%9V$5P0>JES.%
M)P#O\"^QA6>A!XJ7F&.#-PD`N8\!1Z'GA6(6D:)P`G3B9$)I16&"@(5GH0>*
MEYAC@S<)`+F/`4>=XX5B%I&B<`)TXF1":1<E```3!64916%O\$^L(P`%`'&_
M`45MM^_P;[PY<2+X)O1*\$[L!OR7E```@[3D@YQ@/N2!1T``%RD``!,)Z1F7
MF0``@[EI@Z*%2H7O\&_?%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%
M[_!/W67Q%RD``!,)*1>7B0``@[FI?Z*%2H7O\*_;%<$21X.W"0`.![J7F&>8
MXV77F&NA!YCC;?^BA4J%[_"/V67Q%RD``!,)Z1.7B0``@[GI>Z*%2H7O\._7
M%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_#/U67Q%RD``!,)*1&7
MB0``@[DI>**%2H7O\"_4%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%
M[_`/TF7Q%RD``!,)Z0V7B0``@[EI=**%2H7O\&_0%<$21X.W"0`.![J7F&>8
MXV77F&NA!YCC;?^BA4J%[_!/SF7Q%RD``!,)*0N7B0``@[FI<**%2H7O\*_,
M%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_"/RF7Q%RD``!,)Z?^7
MB0``@[GI;**%2H7O\._(%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%
M[_#/QF7Q%RD``!,)J027B0``@[DI::*%2H7O\"_%%<$21X.W"0`.![J7F&>8
MXV77F&NA!YCC;?^BA4J%[_`/PV7Q%RD``!,)Z0&7B0``@[EI9:*%2H7O\&_!
M%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%[_!/OV7Q%RD``!,)*?^7
MB0``@[FI8:*%2H7O\*^]%<$21X.W"0`.![J7F&>8XV77F&NA!YCC;?^BA4J%
M[_"/NV7Q%RD``!,)Z?&7B0``@[GI7:*%2H7O\.^Y%<$21X.W"0`.![J7F&>8
MXV77F&NA!YCC;?^BA4J%[_#/MV7QHH47)0``$P6%^._PS[:JA1G%%R4``!,%
MA?7O\&_FHH47)0``$P4E^._P[[2JA1G%%R4``!,%I?CO\(_DHH47)0``$P7%
M^._P#[.JA07-%R4``!,%1>CO\*_B(F><8+F/`4>IXT)TXG"B=`)YXFF7)0``
MDX5%^!<E```3!47L(6%O\`_@HH47)0``$P5%]>_PCZZJA7G1%R4``!,%1>SO
M\"_>9;_O\.^&`1$BZ`;L%X0```,TQ$Y,`!<E```3!27J'&`^Y(%'[_`/JQ7!
M@T<%``%%B<>3AP?],S7P`")G'&"YCP%'F>?B8$)D!6&"@`%%];?O\`^"01$&
MY._@G]`!)>_@/_L1P0AAHF!!`8*`.7$F]$KP!OP7B0```SE)2*J$3``7)0``
M$P6%[8,W"0`^Y(%'[_!/I!W%(OB#1P4`*H2-PZ:%[^#_UAW-(F>#-PD`N8\!
M1]'C0G3B<*)T`GDA88*`0G0B9X,W"0"YCP%'IH47)0``$P6EZ+WCXG"B=`)Y
M(6%O\._/)H5.[._@G\BJB2*%[^`?R$Z5"07OX)_((HB7)P``DX<GU2:'ER8`
M`).&AM5]5H5%*H3OX+_P(F>#-PD`N8\!1Y'KHH7B:4)T%R4``!,%Q>)5MT[L
M[^"?\R+X3NSOX!_SEX<``).'1QEE<8.X!P$#N(<!D'.4=YA[G'_*^L[VTO(&
MYR+C%XH```,Z"CD#,PH`&OX!0Q<C```3`X/?$PG!`;[\ER<``).')]^JB1KP
M/OP7(P``$P-#R9<G``"3AT?>RH47)0``$P6ER!KT`OC&Z,+LLO"V]+KXON""
MY._P3Y$1Q8-'!0`JA&.4!QZF_M;N[^#?N`$E[^!_XV,.!10`86,+!!0BA>_@
M?[@&!04%[^#_N`-'!`"JA*J*%</:ZA<K```3"^O8)H7:AGU6A47OX/_@`T<4
M`(D$!01U]U9KA`@7)0``$P5%SR&@B&2A!`W!RH7O\.^)*H1MV8-'!0#UU^_P
MSY-]T2*%[^!?T2J$&>T$$(!@`<R#1P0`8XP'#"*%[_#/D5WM@&2A!'7T(H7O
MX/^OJH16A>_@?Z^IG)N$1$`FA>_@OZ_6B)<G``"3A\>\%R@``!,(2-`BAY<F
M``"3AB;0?5:%1:J*[^!?UY,%`!Q6A>_@O\C]5V,8]0#OX!^N'$%%1V.6YPP,
M`5:%[^`?S2J$&>7*1[UF$6?UCV.`YPJ7AP``@[=')8.V"0"(8U:'%R8``!,&
MQL^%1>_@/]"!1')W@S<*`+F/`4=CD`<NNF`:9/9J5GFV>19Z)H7V=%EA@H`B
MA>_@G\,JA*$$XP,%\C6_`40EOV)U)!@9R<J%[^`_^0'%@T<%`(WCB&2A!'WU
M-47:ZN_@GZ*JA*J*%R0``!,$A,`3!S`%6;WOX#^_*H1IW>_@OY\&!04%E;W:
MZFI+[^#?G9L'!0!C!OL$5FN)OQ>'```#-T<:@[8)``AC%R8``!,&YL!6AX5%
M[^`_Q8&_[_"?RW)W@S<*`+F/`4=CFP<B(H4:9+I@5GFV>19Z66%OX-^XRD?>
MYN+B$P<`')/W]Q]CAN<`5FNV:Q9LU;TFA>_@WYC*A:J$%R4``!,%Q<3OX!_M
MJH5C#P40`[4)`._P+]JJBV,(!1!>A>_@/Y4;"P4`C4=CV&<#$P7+_Y<E``"3
MA07"7I7OX'^G">V11V,`^QB;![O_WI<#QP<`DP?P`F,']Q;*A1<E```3!>6E
M[^`_YV'%@T<%`.G#$P<``V..YPJ7)0``DX6EK1<E```3!:6C[_"/E>_@?Z$J
MB)<H``"3B(C*ER<``).'!YQ6AY<F``"3AN:\?5:%12:%[^`?MWU9Q4D7+```
M$PP,R)<K``"3BXN9%RL``!,+B[LEH._@_XP<06.7-P/OX%^<!20JB&+@HHC>
MAU:'VH9]5H5%)H7OX-^RDP4`'":%[^`_I.,()?U6A>_@GZ"FA1<E```3!262
M[_"/C":%[_`?M59KMFL6;/F[@[L)`,6]@45>A>_@_[0JB1W=[^!_^JJ)XTL%
M\I,%9?\!1DJ%[^!?FA,+`1`91MJ%2H7OX'^G`R<!$+='04.3AP<PXQ;W\`-7
M01"19Y.'AU3C'_?NDX7I_`%&2H7OX-^6(`*BA1,&@`)*A>_@_Z.7*```DX@H
MNB*(ER<``).'AXM6AY<F``"3AF:K?5:%12:%(P@!$N_@7Z:9MX.YB0#CB0GH
M3H7OX$_ZC4?C\Z?H<167)0``DX4%J$Z5[^#_C.,9!>;.B[6UVNK>YN+B[^#?
MIZ;^UN[:ZM[FXN+OX/^F.7$B^!>$```#-&3Q2O!.[`;\)O12Z+,'1`"$8Y,)
M00`7B0```SDI[8/'!`O.A1<E```3!46&`S<)`#KD`4>CB/0*[^#?R!G%`T<%
M`),'$`-C"_<2[_!/Y;,'1`"$8R:%C48%1I<E``"3A>6B[^#O]JJ$'<$<:3,'
M1``(8XQC%R8``!,&QJ'OX$_VG&B,8]Q%$Y>7`F-&!Q"S!T0`B&.-1@5&ER4`
M`).%!:#OX`_SJH07B@``$PJJZ@W!SH47%0``$P7E=^_@O\`JAGG!G&@S!T0`
M"&.,8^_@3_&S!T0`A&,%1I<E``"3A86<)H7OX._DJH47)@``$P8&G2:%[^#O
M[A*4'&#.A1<5```3!45RHX@'"N_@W[LC.*H`*H0YQ9,%`!PBA>_@?X$;!Q4`
MA4=C\.<"Q4=C#?4`@S>*`*J&(H:,8Q<E```3!06;[^`?AB)G@S<)`+F/`4>Q
MZ^)P0G2B=`)YXFE":B%A@H`#-8H`[_`?G2,XJ@`JA%WQ%R4``!,%!97OX)^"
M@T<5`..*!^S9M0,WB@"<:`QCB&/OX-_^-;^S!T0`B&/OX$_]_;7OX/^+>7$B
M\";L2N@&]!>)```#.8G3@S<)`#[D@4>JA._PK[V3!?`"*H3OX$_[&<$3!!4`
M(H7OX(_W*H1,`!<5```3!85L[^#?K0'-@T<%`(G+$P<``V.&YP"!Q(/'!`")
M[R)G@S<)`+F/`4>5[Z)P`G3B9$)I16&"@!%&EQ4``).%I78BA>_@C\]A_2)G
M@S<)`+F/`4>)ZP)THG!":2:%XF1%86_@7[COX'^!$P$!U",X@2HC/!$J(S21
M*B,P(2LC/#$I(SA!*1>$```#-.3'-`#!;GU?'&`C-/$H@4>3"(4#DP*%!S:(
M$U\/`K</_P"3C@[P`[8(`$$(H0B3508"$Q>&`9,3A@"35X8"$UZ&`)-4A@,3
MDX4!,W?G`;/S\P&S]]<!,V=W`#-^W@'%CS-SXP&B!3-GQP$;5H8!L^=G`+/U
M]0%1C\V/(SCH_B,\^/[CDA+[_57&?V9_"F?B;@)^(G/">&)XAF.3A`8@@9$1
MH+*#L&*<8KJ"H0:QC[/']P&SQ]<!$Y<7`/V#78]MC[C^^H_RCA:/&HY&@\*(
M'HCCF9;\@SX%`*)O`S@%`0,SA0"#.(4!`SX%`C>'@EH3!Y>9D]>^`1.67@!=
MCKJ?$U\C`),7XP%MCO*?LT88`;/GYP&S]F8`?I;";S/_MP"SQA8!-I:S1N@!
M;8ZS]M8!NI^3$E8`DU2V`<:?L\8&`?Z6L^^2`!/9+@"3D^X!_I;B;[/C(P&S
MQW<`\8^ZG^V.L\?G`<*?DY16`!/9M@&3$N8!_I<)@H)_L^+"`#/F)`&RES/&
M4P"ZG[/SLP!UCNV/?I\S1G8`DY17`!/9MP&3G^8!>I:)@B)_L^_?`+/F)`$V
MEK/&\@%MCK/RL@#]CCJ?'I^3%%8`$UFV`;/&5@"3D^<!B8.SX_,`^I:SYR0!
MOI8S_[8`PG:SQW\`\8^S_[\`NI:6EI,47P`36;\!L\?W`;:7L^8D`;:7DQ+F
M`0F"L^+"`#/VMP#B=[/&4P"S]N8!L_.S`+J7_I>3%%8`$UFV`;/&=@"^EK/G
M)`&^EI,?[P$37R\`L^_O`3/_M@"&9K/'\@'QC[/RL@"ZEIZ6DQ1?`!-9OP&S
MQU<`MI>SYB0!MI>3$^8!"8*SX\,`,_:W`*9GL\9_`+/VY@&S_[\`NI>6EY,4
M5@`36;8!L\;V`;Z6L^<D`;Z6DQ+O`1-?+P"SXN(!,_^V`,9FL\=3`/&/L_.S
M`+J6_I:3%%\`$UF_`;/'=P"VE[/F)`&VEY,?Y@$)@K/OSP`S]K<`YF>SQO(!
ML_;F`;/RL@"ZEYZ7DQ16`!-9M@&SQE8`OI:SYR0!OI:3$^\!$U\O`+/CXP$S
M_[8`AG:SQW\`\8^S_[\`NI:6EI,47P`36;\!L\?W`;:7L^8D`;:7DQ+F`0F"
ML^+"`#/VMP"F=[/&4P"S]N8!L_.S`+J7_I>3%%8`$UFV`;/&=@"^EK/G)`&^
MEI,?[P$37R\`L^_O`3/_M@#&=K/'\@'QC[/RL@"ZEIZ6DQ1?`!-9OP&SQU<`
MMI>SYB0!MI>3$^8!"8*SX\,`,_:W`.9WL\9_`+/VY@&S_[\`NI>6EY,45@`3
M6;8!L\;V`;Z6L^<D`;Z6DQ+O`1-?+P"SXN(!,_^V`(IFL\=3`/&/L_.S`+J6
M_I:3%%\`$UF_`;/'=P"VE[/F)`&VEY,?Y@$)@K/OSP`S]K<`JF>SQO(!L_;F
M`;/RL@"ZEYZ7DU2V`9,35@"SQE8`$QGO`;Z6$U\O`+/GDP#*8S-OZ0&^EK/'
M[P'MCK/_OP"ZD_&/GI*3U+8!L\?W`9.35@"SXY,`EI?J9),2Y@$)@K/BP@">
ME^V/,T9?`+J4,W^_`!/9MP%UCI.35P"FGS-&Y@&SXR,!L_.S`'Z6DY_F`8F"
M'I:S[]\`"GFS=+8`L\;R`?V.L_*R`).35`"3V;0!.IDSQU8`L^8S`9.3YP&)
M@[/C\P!*G[/'?P#MCGJ7L8\J=C,/UP`W]]EN$P<7NK-YOP`3V;D!.I:3EED`
M%I;MC[/F)@&RE^V.OI:3DN0!RG>)@+/BD@`S^;8`,\93`+/_OP"35+D!NI<S
M3^8!$Q99`#-_OP#^ET6.^I=MCCZ6DY_I`>IWD]DI`+/O/P&S=+8`,\_R`;/S
MLP"3V;0!NI<S3]\`DY94`#-_OP">E[/F-@'ZE^V.OI83'^D!CF<362D`,V\O
M`;/SM@`SR>\!L_FR`+J7LT+)`!/9LP$3EE,`L_*R`,Z7,V8F`9:7;8X^EI.2
MY`&N9XF`L^*2`#-)7P"S=+8`L_F_`+J7LT_9`!/9M`&3EE0`L_^_`,Z7L^8F
M`?Z7[8Z^EI.?XP'.9Y/3(P"S[W\`,\GR`;/SM@"S>;\`NI<S3\D`$]FS`1.6
M4P`S?[\`SI<S9B8!^I=MCCZ6$Y_D`>YGB8`S;Y\`,\GO`;-TM@"S^;(`NI>S
M0MD`$]FT`9.65`"S\K(`SI>SYB8!EI?MCKZ6DY+C`8YWD],C`+/B<@`S25\`
ML_.V`+/YOP"ZE[-/R0`3V;,!$Y93`+/_OP#.ES-F)@'^EVV./I:3G^0!KG>)
M@+/OGP`SR?(!LW2V`+-YOP"ZES-/V0`3V;0!DY94`#-_OP#.E[/F)@'ZE^V.
MOI83G^,!SG>3TR,`,V]_`#/)[P&S\[8`L_FR`+J7LT+)`!/9LP$3EE,`L_*R
M`,Z7,V8F`9:7;8X^EI.2Y`'N=XF`L^*2`#-)7P"S=+8`L_F_`+J7LT_9`!/9
MM`&3EE0`L_^_`,Z7L^8F`?Z7[8Z^EI.?XP&29Y/3(P"S[W\`,\GR`;/SM@"S
M>;\`NI<S3\D`$]FS`1.64P`S?[\`SI<S9B8!^I=MCCZ6$Y_D`;)GB8`S;Y\`
M,\GO`;-TM@"S^;(`NI>S0MD`$]FT`9.65`"S\K(`SI>SYB8!EI?MCKZ6DY+C
M`=)GD],C`+/B<@`S25\`L_.V`+/YOP"ZE[-/R0`3V;,!$Y93`+/_OP#.ES-F
M)@'^EVV./I:3G^0!\F>)@+/OGP`SR?(!LW2V`+-YOP"ZES-/V0`3V;0!DY94
M`#-_OP#.E[/F)@'ZE^V.OI83G^,!DG>3TR,`,V]_`#/)[P&S\[8`L_FR`+J7
MLT+)`!/9LP$3EE,`L_*R`,Z7,V8F`9:7;8X^EI.2Y`&R=XF`L^*2`#-)7P"S
M=+8`L_F_`+J7LT_9`!/9M`&3EE0`L_^_`,Z7L^8F`?Z7[8Z^EI.?XP'2=Y/3
M(P"S[W\`,_FV`+/#\@&S>;\`NI<SS\,`DU.Y`1,660`S?[\`SI<S9G8`;8[Z
MES./QP"3D^0!\G>)@+/CDP`SQG\`LW2_`+/RL@"ZE[&.[8Z3V;0!EI>3DE0`
MMI>SYC(!MI<3%ND!EF8362D`,V8F`3/)PP"S\K<`L_^_`+-'Z0&ZEI/9L@'^
MEA.94@"S_[<`,VDY`?Z6RI83G^0!B8`S;Y\`-_?&([-TM@#]5_6-MF:!DPH'
M$P?'S;-__P`S9N8!,_GT`;J6,W96`+/S\P"VDY/9M0$S9B8!$YE5`!Z6LV,Y
M`1Z6LW/V`).6X@%69I/2(@"SYE8`L_+V`#-OWP`S^5\`.I8S?[\`LI23V;,!
M,V\O`1.94P`FG[-D.0$3EN4!)I^)@?9D38ZS=?8`T8XS?_\`,_FR`+/V=@"Z
ME/Z4DUF_`;/F)@$3&5\`II:S9#D!$YKC`9/?(P"FEI9TLV_Z`;/S_P`S9O8!
M_8XS^74`NI0S=N8!II(S9B8!DY16`!/9M@&SY"0!%I:3&>\!)I837R\`MG0S
M[^D!LW+_`+/O[P%]CC/Y4P"S_]\`NI2S[R\!KI03&58`DUFV`9.5Y@&)@M6-
MLX:?`+-O.0'^EM9_L_3U`#-OOP#]CC/YD@"ZGS-_SP`S;R\!_I,3F58`D]FV
M`9,?Y@$)@K/OSP`S!G\`,V\Y`7J6=G^S\_\`L^7U`7V.,_ET`#J?]8VSY24!
M^I(3&58`DUFV`1.?Y@&)@C-OWP"SAE4`LV4Y`:Z6FF6S<O\`L^_O`?V.,_E3
M`+J5L__/`+/O+P&NE!.95@"3V;8!DQ7F`0F"T8TSAI\`LV\Y`7Z6NF^S]/4`
M,V^_`'V.,_F2`+J?,W_?`#-O+P'^DQ,95@"36;8!DY_F`8F"L^_?`+,&?P`S
M;SD!^I9:;[/S_P"SY?4!_8XS^70`.I_QC;/E)0'ZDA.95@"3V;8!$Q_F`0F"
M,V_/`#.&50"S93D!+I;Z9;-R_P"S[^\!?8XS^5,`NI6S_]\`L^\O`:Z4$QE6
M`)-9M@&3E>8!B8+5C;.&GP"S;SD!_I::?[/T]0`S;[\`_8XS^9(`NI\S?\\`
M,V\O`?Z3$YE6`)/9M@&3'^8!"8*S[\\`,P9_`#-O.0%ZECI_L_/_`+/E]0%]
MCC/Y=``ZG_6-L^4E`?J2$QE6`)-9M@$3G^8!B8(S;]\`LX95`+-E.0&NEMIU
MLW+_`+/O[P']CC/Y4P"ZE;/_SP"S[R\!KI03F58`D]FV`9,5Y@$)@M&-,X:?
M`+-D.0$FEOITL__U`#-OOP!]CC/Y\@$S?]\`NI0S;R\!GI03&58`DUFV`9.3
MY@&)@K/CTP"S!I\`LV0Y`1YI,__S`+/E=0"FEO&-L_3O`3J9_8X6F<6-DYE6
M`!/:M@&34B8`DQ3F`<J5/FFSY%0`,^9)`;/R]`"RE3/FDP!UCK/S]0`ZF;-U
M7P!^F9.94P`3VK,!38Z3WR8`DY7F`4J6L^9)`;/E]0$VEK/FM`"S=/8`7F:S
M__4`,_GR`;/V=@`ZEGJ6L^8F`1.?5``3V;0!,V\O`;*6?FD3EN,!D],C`#-F
M=@"S<_8`^I;1C?V.,_I_`.6-.ID3GU8`D]FV`1:9L^5%`;-B/P'*E1/?)``3
MF>0!LV3I`1Y_L_+R`):518ZS\O0`,_GU`#/Z4P!UCCJ?DUFY`1,760!^GS-F
M1@&S;S<!>I:3F>8!$]\F`#/OZ0&SQN0!L___`*V.-[>8,KYULI\*!Q,'9QVS
M^?\`D]2Y`;J5$Y99`)Z5_8Y%CI,3Z0$362D`L^,C`7V.KI:SA<8`,T9_`#-&
M]@'>?[/T]0`3V;0!NI^3EE0`EI]]CK/F)@']CGZ6-I:3G^D!_G:3V2D`L^\_
M`3-Y]@"SPO,!LWG_`+J6,\^R`)-2N0&3%5D`,W__`,Z6L^55`/J6_8VVE1.?
MY`&#-@$@B8`S;Y\`L\+O`;/T]0"S\_,`D]FT`;J6L\+"`!.65`"S\O(`GI8S
M9C8!EI9]CC:6DQ+I`8,V@2`362D`L^(B`;-S]@`S25\`L_G_`+J6LT^Y`!/9
MLP&3E5,`L___`,Z6L^4E`?Z6_8VVE9.?Y`&#-@$AB8"S[Y\`,\GR`;/T]0"S
M>?\`NI8S3\D`$]FT`1.65``S?_\`SI8S9B8!^I9]CC:6$Y_C`8,V@2&3TR,`
M,V]_`#/)[P&S<_8`L_GR`+J6LT*Y`!/9LP&3E5,`L_+R`,Z6L^4E`9:6_8VV
ME9.2Y`&#-@$BB8"SXI(`,TE?`+/T]0"S^?\`NI:S3\D`$]FT`1.65`"S__\`
MSI8S9B8!_I9]CC:6DY_C`8,V@2*3TR,`L^]_`#/)\@&S<_8`LWG_`+J6,T^Y
M`!/9LP&3E5,`,W__`,Z6L^4E`?J6_8VVE1.?Y`&#-@$CB8`S;Y\`,\GO`;/T
M]0"S^?(`NI:S0LD`$]FT`1.65`"S\O(`SI8S9B8!EI9]CC:6DY+C`8,V@2.3
MTR,`L^)R`#-)7P"S<_8`L_G_`+J6LT^Y`!/9LP&3E5,`L___`,Z6L^4E`?Z6
M_8VVE9.?Y`&#-@$DB8"S[Y\`,\GR`;/T]0"S>?\`NI8S3\D`$]FT`1.65``S
M?_\`SI8S9B8!^I9]CC:6$Y_C`8,V@223TR,`,V]_`#/)[P&S<_8`L_GR`+J6
MLT*Y`!/9LP&3E5,`L_+R`,Z6L^4E`9:6_8VVE9.2Y`&#-@$EB8"SXI(`,TE?
M`+/T]0"S^?\`NI:S3\D`$]FT`1.65`"S__\`SI8S9B8!_I9]CC:6DY_C`8,V
M@263TR,`L^]_`#/)\@&S<_8`LWG_`+J6,T^Y`!/9LP&3E5,`,W__`,Z6L^4E
M`?J6_8VVE1.?Y`&#-@$FB8`S;Y\`,_GU`+/$[P&S^?(`NI:SPL0`DU2Y`1,6
M60"S\O(`SI9%CI:6?8XVEI.4XP&#-H$FD],C`+/D=`"S0I\`LW/V`+/Y_P"Z
MEK//L@"3TK,!DY53`+/__P#.EK/E50#]C?Z6LX^V`),2Z0&#-@$G$UDI`+/B
M(@&SQ50`,_G_`#-__P"36;D!NI:QC1,660#]C?J6,V8V`7V.KI:SA<8`$Y_C
M`0,V@2>3TR,`,V]_`+/&X@&S\_4`_8PZEK/&]@']CB:6D]FS`9.44P`VEK/F
M-`$VEH,V`2B3'^D!$UDI`+/O+P&ZEK-$_P$S=_8`]I:S\O(`,\:T`'V.DQ57
M`)->MP&6EK*6,^;5`9.5XP&3TR,`LI:SY74`_8XZDS,&SP$SAP4!LX4?`7V/
M%.']C;-V\P#QCQCI'/$4Y0SM`S>!*!Q@N8\!1X7C@S"!*P,T`2N#-($J`SD!
M*H,Y@2D#.@$I$P$!+(*`[]#/VD$1$P4`"`;D[]`/J[=V74PW=^EAMR5%9Y.%
M%3"&!C=6,A`&!PSADX;FSY=%``"#M65`$P9F1Q,'!Q\,Y13I$.T8\2,T!0(C
M.`4"(RP%!J)@00&"@#EQ(O@F]$KP5N0&_$[L4N@8=9,7-@`4>;J7@A>!DS.W
MYP"JA+J6*%T35]8!-I><])CX,HDNA).*A`,Q[9,'\`-CW"<)&PD)_!M::0";
M"1H`F@FBF:*%$P8`!%:%[]"/L1,$!`0FA>_@W\WC%33_&QIJ`#L)24%*ALZ%
M5H7OT(^O(ZPD!^)P0G2B=`)YXFE":J)J(6&"@),)``2[AZE`OHEC2O8"&XH)
M`).*A`-2AJ*%5I7OT"^LO%P3!P`$NX;Y`+3<XY'F_":%.PDY05*4[^!?QZVW
MLHGYMZ*)<;]Y<2+P)NQ2X`;T2NA.Y(.YA0(3BH4#DP8`^!/6.0`3=O8#,P?*
M``.Y!0.3!Q8`(P#7`!,'@`,NA*J$!29C5_<2$P<`!!&?D48S!?H`8W77%(E'
M8WGW$F,4!Q(BA>_@O\`3!H`#@452A>_0#[B35@D!$U>)`)/V]@^B!IM7B0$3
M=_</0@?5CQ-Y^0]B"=F/&]:)`9/6"0$"%K/G)P$3UXD`D_;V#Z(6T8\3=_</
M0A?5C^(9V8^SYS<!//@BA>_@O[H<8"*%X8,C@/0`'&#!@Z.`]``<8*&#(X'T
M`!Q@HX'T`!QDX8,C@O0`'&3!@Z."]``<9*&#(X/T`!QDHX/T`!QHX8,CA/0`
M'&C!@Z.$]``<:*&#(X7T`!QHHX7T`!QLX8,CAO0`'&S!@Z.&]``<;*&#(X?T
M`!QLHX?T`!QPX8,CB/0`''#!@Z.(]``<<*&#(XGT`!QPHXGT``)THG#B9$)I
MHFD":D5A;]`OFQ,'@`,[!L=`@44S!?H`[]`/I\6](P`%`.&](P`%`*,`!0!Y
M%PD%XP4'[.VW(P`%`*,`!0`C`04`HP$%`'$7B4<1!>-E]^K1OY=F``"#MF92
M;]#OAP```0`"```````E<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A
M9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN=&5R;F%L<SHZ4$%2.CI"3T]4
M`````&5X90``````+W!R;V,O)6DO)7,``````"X`````````4$%27U1%35``
M`````````%!!4E]04D]'3D%-10`````Z`````````"\`````````)7,E<R5S
M``!015),-4Q)0@``````````4$523$Q)0@!015),-4]05```````````4$52
M3$E/``!005)?24Y)5$E!3$E:140`4$%27U-005=.140``````%!!4E]#3$5!
M3@````````!005)?1$5"54<`````````4$%27T-!0TA%`````````%!!4E]'
M3$]"04Q?1$5"54<``````````%!!4E]'3$]"04Q?5$U01$E2`````````%!!
M4E]435!$25(```````!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!
M3@``````````,0````````!,1%],24)205)97U!!5$@`4UE35$5-```O=&UP
M`````%5315(`````55-%4DY!344``````````"4P,G@`````<&%R+0`````E
M<R5S)7,E<P``````````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E
M('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@
M86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H```````!0051(`````'!A<FP`
M````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S
M)7-T96UP+25U+25U)7,``````````!@`````````<&5R;``````P````````
M`%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4X````56YA8FQE('1O(&-R
M96%T92!C86-H92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H``````````"UE````````+2T```````!435!$25(``%1%35!$25(`5$5-
M4`````!435```````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@
M)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE
M;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F
M9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!
M1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@
M(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'
M24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@
M*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B
M=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@
M*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES
M(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@
M>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S
M:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X
M*"1B=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D[
M"GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P
M87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*
M14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E
M;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E
M8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?
M=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=
M*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER
M(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@
M*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@
M/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2
M(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@
M/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M
M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;
M(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@
M+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X
M<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M
M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M
M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"
M3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@
M>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)5
M1WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I
M;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z
M35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@
M("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?
M<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA
M;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A
M<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P
M<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O
M9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S
M($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?
M<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ
M<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL
M92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!
M4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#
M2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII
M9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*
M;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*
M;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(
M+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(
M+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C
M:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%
M<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?
M;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T
M:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D
M8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@
M9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%
M("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D
M8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A
M8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*
M;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE
M?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M
M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?
M;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O
M+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)
M3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I
M;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^
M8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E
M:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I
M;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G
M+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z
M("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D
M.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE
M("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=
M*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O
M0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q
M=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:
M25!?34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S
M96-T:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*
M)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C
M('-T87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD
M;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!0
M7U)%55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@
M<')O8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP
M87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP
M("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?
M<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@
M86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.
M5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO
M<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!
M4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO
M(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L
M<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G
M8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2![
M"B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE
M="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^
M(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=
M.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS
M:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID
M96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!0
M05(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6
M.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]
M"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2![
M"GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*
M;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ
M<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A
M<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI
M=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%
M<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?
M<&%R(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H
M+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE
M("(D<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE
M('%Q6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@
M)%!+6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`[
M"FUY("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-2
M14%4*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U
M="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D
M;&]A9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2![
M"G)E860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI]
M(&5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*
M:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC
M(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L
M;V%D97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@
M4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII
M;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@
M>R`A+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH
M)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG
M+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK
M*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@
M)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[
M("`@("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N
M.PIF;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F
M:6QE+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL
M("1F8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H
M)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I
M(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R
M+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD
M,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF
M("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B
M+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M
M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F
M:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P
M<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D
M9FEL92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H
M)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL
M;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`]
M(#PD=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!
M4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*
M4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E
M;G0L("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH
M)TXG+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!
M<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*
M<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE
M('%Q6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A
M73L*;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP
M*2!["B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O
M9B`B)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I
M;G0H(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N
M86UE*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F
M:"P@,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*
M)&-A8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@
M/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C
M86-H95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T
M:"`D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!
M0TA%(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A
M9&5R*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'
M24,I.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL
M97(@;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*
M>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA
M;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)
M3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92!Q<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D
M:6YG('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS
M971#:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@
M)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H
M(D5X=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%
M35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H
M(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB
M97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF
M:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S
M:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI
M"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]
M($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T
M7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M
M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M
M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N
M86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?
M;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T
M5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O
M("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>
M3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD
M<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@
M)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C
M+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@
M)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA
M;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA
M;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H
M)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0
M871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H
M(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U
M:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97([
M"G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A
M<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O
M;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T[
M"F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA
M<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R
M<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@
M?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A
M;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?
M=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*
M?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]4
M35!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-
M4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@
M+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I
M9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D
M/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E
M<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D
M<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA
M;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG
M.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP
M86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM
M>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D
M:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B
M+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z
M("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H
M*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E
M=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@
M)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP
M0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T
M7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L
M(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^
M(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S
M92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M
M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S
M>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@
M/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@
M+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S
M+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M
M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D
M9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E
M;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F
M:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*
M8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA
M;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I
M.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII
M9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!2
M3T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N
M86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O
M9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D
M<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D
M9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@
M*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y
M<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O
M7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X
M:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0
M?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA
M<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE
M?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B
M*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D
M96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B
M(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK
M(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:
M141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@
M0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]
M"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB
M4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%
M3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*
M9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC
M``````````!#04-(10``B:O-[P`````!&P,[Y````!L```"0D?__%`8``!R3
M___\````U)/__Q`!``"`E/__?`$``-J4__^H`0``X)7__P`"``#>EO__3`(`
M`(R8__^L`@``<IG__^P"``#,F?__$`,``/29__\D`P``LIK__UP#``"TFO__
M<`,``(J<___$`P``K)S__^0#``"NG?__*`0```:A__]<!```5*'__X`$``!L
MH?__G`0``$2B___T!```!J?__Z`%``"VJ/__V`4``%ZI__](!@``R+O__X`&
M```<O/__H`8``/B\___8!@``JK[__Q`'````````$``````````#>E(``7P!
M`1L-`@`0````&````!B2__\B``````<!`&@````L````O)+__ZP`````0@Y`
M1($"B`1,EA!2D@B3"I0,9HD&E0YFR4+20M-"U$+50M9"P43(0@X`0@Y`@0*(
M!(D&D@B3"I0,E0Z6$%#)TM/4U=9$EA!"UD22"),*E`R6$$;20M-"U$+6`"@`
M``"8````_)+__UH`````0@ZP`4:(!(D&@0("1@K!0LA"R4(.`$(+````5```
M`,0````JD___!@$```!"#L`!1),*@0)8B`1&R%#!0M-"#@!"#L`!@0*(!),*
M1(D&D@ARE`P"5M14"LA"R4+20@M2E`Q(R,G2U$B(!(D&D@B4#````$@````<
M`0``V)/___X`````0@Y@1(@$6@[@@`23"I0,EA"!`HD&D@B5#I<2F!0"P@H.
M8$+!0LA"R4+20M-"U$+50M9"UT+80@X`0@M<````:`$``(J4__^N`0```$(.
M8%2(!(D&D@B4#($"DPJ5#I80`M`*P4+(0LE"TD+30M1"U4+60@X`0@MNEQ*8
M%`)6"M="V$0+5-?81)<2F!1&U]A$EQ*8%$;70M@````\````R`$``-B5___F
M`````$(.4$25#EH.T""(!(D&D@B3"I0,@0(">@H.4$+!0LA"R4+20M-"U$+5
M0@X`0@L`(`````@"``!^EO__6@````!"#A!"B`1*@0)HR$+!7@X`````$```
M`"P"``"TEO__*``````````T````0`(``,B6__^^`````$(.4$2)!E`.T$"!
M`H@$D@B3"@*4"@Y00L%$R$+)0M)"TT(.`$(+`!````!X`@``3I?__P(`````
M````4````(P"```\E___U@$```!&#O`!9@[P(8@$B0:2")@4@0*3"I0,E0Z6
M$)<2F1::&`)B"@[P`4+!0LA"R4+20M-"U$+50M9"UT+80ME"VD(.`$(+'```
M`.`"``"^F/__(@````!"#A!(B`2!`E#(0L%"#@!```````,``,"8__\"`0``
M`$(.,%(.L""2"($"B`2)!@*H"@XP0L%"R$+)0M)"#@!""U8*#C!"P4+(0LE"
MTDH.`$0+`#````!$`P``?IG__U@#````0@Y`2H@$B0:2"),*@0(#"@,*R$+!
M0LE"TD+34@X`1`L````@````>`,``**<__].`````$(.($2(!($">@K!0LA"
M#@!""P`8````G`,``,R<__\8`````$(.$$*!`E#!0@X`5````+@#``#(G/__
MV`````!"#D!&B0:2"($":(@$6@K(0L%"R4+20@X`0@M"R%C!0LE"TD(.`$0.
M0($"B`2)!I((1`J3"@)"TT+(2@M"DPI$R--$B`23"J@````0!```2)W__\($
M````2@Z0`UJ2"),*E`R!`H@$`FR)!I4.;I808-8#\@`*P4+(0M5"TD+30M1$
MR4(.`$(+<@J6$%8+5)804-9BR=56R$+!0M)"TT+40@X`1`Z0`X$"B`2)!I((
MDPJ4#)4.EA!.EQ*8%$;60M="V$*6$)<2F!0#,`$*UD+70MA""P+&UM?81I80
MEQ*8%$3)U=;7V$J)!I4.EA"7$I@4```T````O`0``%ZA__^P`0```$(.0$*(
M!%*2"),*@0*)!I0,`T8!"L%"R$+)0M)"TT+40@X`0@L``#@```#T!```UJ+_
M_Z@`````0@XP2(@$B0:2"($"`F(*P4+(0LE"TD(.`$(+8`K(0L%"TD3)0@X`
M1`L``#`````P!0``=(O__XP!````0@Y@3($"B0:(!)((DPH##@$*P4+(0LE"
MTT320@X`0@L````T````9`4```ZC__]J$@```$0.P`58B`2!`HD&D@B3"I0,
M`S`2"L%$R$3)1-)$TT341`X`0@L``!P```"<!0``0+7__U0`````0@X01H$"
M`DC!0@X`````-````+P%``!TM?__W`````!"#D!.B`2)!I((E0Z!`I,*E`P"
M=@K!0LA"R4+20M-"U$+50@X`0@LT````]`4``!BV__^R`0```$(.,$R(!(D&
ME`R!`I((DPH#3`$*R$+!0LE"TD+30M1"#@!$"P```!`````L!@``DK?__PP`
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````$`````````W@(````````!````````
M`.X"`````````0````````#X`@```````"``````````V*T````````A````
M``````@`````````&0````````#@K0```````!L`````````"``````````:
M`````````.BM````````'``````````(`````````/7^_V\`````V`(`````
M```%``````````@-````````!@````````#``P````````H`````````F@0`
M```````+`````````!@`````````%0````````````````````,`````````
M4+`````````"`````````$`%````````%``````````'`````````!<`````
M````V!0````````'`````````,@2````````"`````````!0!P````````D`
M````````&``````````>``````````@`````````^___;P`````!```(````
M`/[__V\`````:!(```````#___]O``````(`````````\/__;P````"B$0``
M`````/G__V\`````"P``````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````"E!!4BYP;0H`````````````````````````
M````````````````````````````````````````````````````````````
M__________\``````````"`:````````(!H````````@&@```````"`:````
M````(!H````````@&@```````"`:````````(!H````````@&@```````"`:
M````````(!H````````@&@```````"`:````````(!H````````@&@``````
M`"`:````````(!H````````@&@```````"`:````````(!H````````@&@``
M`````"`:````````(!H````````@&@```````"`:````````(!H````````@
M&@```````"`:````````(!H````````@&@```````"`:````````(!H`````
M```@&@```````"`:````````(!H````````@&@```````"`:````````(!H`
M```````@&@```````"`:````````(!H````````@&@```````"`:````````
M(!H````````@&@```````"`:````````(!H````````@&@```````"`:````
M````(!H````````@&@```````"`:````````(!H````````@&@```````"`:
M````````(!H```````#PK0``````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````$=#0SH@*%5B=6YT=2`Q,RXR
M+C`M-'5B=6YT=3,I(#$S+C(N,`!!4@```')I<V-V``%(````!!`%<G8V-&DR
M<#%?;3)P,%]A,G`Q7V8R<#)?9#)P,E]C,G`P7WII8W-R,G`P7WII9F5N8V5I
M,G`P7WIM;75L,7`P```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I
M;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R
M`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N
M<&QT`"YT97AT`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+G!R
M96EN:71?87)R87D`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M:6,`
M+F1A=&$`+F=O=``N8G-S`"YC;VUM96YT`"YR:7-C=BYA='1R:6)U=&5S````
M````````````````````````````````````````````````````````````
M````````````````````````"P````$````"`````````'`"````````<`(`
M```````A`````````````````````0```````````````````!,````'````
M`@````````"4`@```````)0"````````)`````````````````````0`````
M```````````````F````!P````(`````````N`(```````"X`@```````"``
M```````````````````$````````````````````-````/;__V\"````````
M`-@"````````V`(```````#H``````````4`````````"```````````````
M`````#X````+`````@````````#``P```````,`#````````2`D````````&
M`````@````@`````````&`````````!&`````P````(`````````"`T`````
M```(#0```````)H$```````````````````!````````````````````3@``
M`/___V\"`````````*(1````````HA$```````#&``````````4`````````
M`@`````````"`````````%L```#^__]O`@````````!H$@```````&@2````
M````8``````````&`````@````@```````````````````!J````!`````(`
M````````R!(```````#($@```````!`"````````!0`````````(````````
M`!@`````````=`````0```!"`````````-@4````````V!0```````!`!0``
M``````4````5````"``````````8`````````'D````!````!@`````````@
M&@```````"`:````````H`,``````````````````!``````````$```````
M``!^`````0````8`````````P!T```````#`'0```````"8M````````````
M```````$````````````````````A`````$````"`````````.A*````````
MZ$H```````!(00``````````````````"````````````````````(P````!
M`````@`````````PC````````#",````````Y`````````````````````0`
M``````````````````":`````0````(`````````&(T````````8C0``````
M`$`&```````````````````(````````````````````I````!`````#````
M`````-BM````````V)T````````(`````````````````````0`````````(
M`````````+,````.`````P````````#@K0```````."=````````"```````
M``````````````@`````````"`````````"_````#P````,`````````Z*T`
M``````#HG0````````@````````````````````(``````````@`````````
MRP````8````#`````````/"M````````\)T````````0`@````````8`````
M````"``````````0`````````-0````!`````P``````````L`````````"@
M````````4`````````````````````@```````````````````#:`````0``
M``,`````````4+````````!0H````````#@"```````````````````(````
M``````@`````````WP````@````#`````````(BR````````B*(````````H
M````````````````````"````````````````````.0````!````,```````
M`````````````(BB````````)0````````````````````$``````````0``
M``````#M`````P``<`````````````````````"MH@```````%,`````````
M```````````!`````````````````````0````,`````````````````````
K`````*,```````#_`````````````````````0``````````````````````
